# Release History

## 11.0.0b1 (2026-04-24)

### Features Added

  - Client `RecoveryServicesBackupClient` added method `send_request`
  - Model `AzureFileShareRecoveryPoint` added property `threat_status`
  - Model `AzureFileShareRecoveryPoint` added property `threat_info`
  - Model `AzureFileshareProtectedItem` added property `source_side_scan_info`
  - Model `AzureIaaSClassicComputeVMProtectedItem` added property `source_side_scan_info`
  - Model `AzureIaaSComputeVMProtectedItem` added property `source_side_scan_info`
  - Model `AzureIaaSVMProtectedItem` added property `source_side_scan_info`
  - Model `AzureSqlProtectedItem` added property `source_side_scan_info`
  - Model `AzureVmWorkloadProtectedItem` added property `source_side_scan_info`
  - Model `AzureVmWorkloadProtectionPolicy` added property `vm_workload_policy_type`
  - Model `AzureVmWorkloadSAPAseDatabaseProtectedItem` added property `source_side_scan_info`
  - Model `AzureVmWorkloadSAPHanaDBInstanceProtectedItem` added property `source_side_scan_info`
  - Model `AzureVmWorkloadSAPHanaDatabaseProtectedItem` added property `source_side_scan_info`
  - Model `AzureVmWorkloadSQLDatabaseProtectedItem` added property `parent_protected_item`
  - Model `AzureVmWorkloadSQLDatabaseProtectedItem` added property `protection_level`
  - Model `AzureVmWorkloadSQLDatabaseProtectedItem` added property `source_side_scan_info`
  - Model `AzureWorkloadPointInTimeRecoveryPoint` added property `threat_status`
  - Model `AzureWorkloadPointInTimeRecoveryPoint` added property `threat_info`
  - Model `AzureWorkloadRecoveryPoint` added property `threat_status`
  - Model `AzureWorkloadRecoveryPoint` added property `threat_info`
  - Model `AzureWorkloadSAPAsePointInTimeRecoveryPoint` added property `threat_status`
  - Model `AzureWorkloadSAPAsePointInTimeRecoveryPoint` added property `threat_info`
  - Model `AzureWorkloadSAPAseRecoveryPoint` added property `threat_status`
  - Model `AzureWorkloadSAPAseRecoveryPoint` added property `threat_info`
  - Model `AzureWorkloadSAPHanaPointInTimeRecoveryPoint` added property `threat_status`
  - Model `AzureWorkloadSAPHanaPointInTimeRecoveryPoint` added property `threat_info`
  - Model `AzureWorkloadSAPHanaRecoveryPoint` added property `threat_status`
  - Model `AzureWorkloadSAPHanaRecoveryPoint` added property `threat_info`
  - Model `AzureWorkloadSQLPointInTimeRecoveryPoint` added property `threat_status`
  - Model `AzureWorkloadSQLPointInTimeRecoveryPoint` added property `threat_info`
  - Model `AzureWorkloadSQLRecoveryPoint` added property `threat_status`
  - Model `AzureWorkloadSQLRecoveryPoint` added property `threat_info`
  - Model `AzureWorkloadSQLRecoveryPointExtendedInfo` added property `included_databases`
  - Model `BackupEngineBaseResource` added property `system_data`
  - Model `BackupRequestResource` added property `system_data`
  - Model `BackupResourceConfigResource` added property `system_data`
  - Model `BackupResourceEncryptionConfigExtendedResource` added property `system_data`
  - Model `BackupResourceEncryptionConfigResource` added property `system_data`
  - Model `BackupResourceVaultConfigResource` added property `system_data`
  - Model `DPMProtectedItem` added property `source_side_scan_info`
  - Model `GenericProtectedItem` added property `source_side_scan_info`
  - Model `GenericRecoveryPoint` added property `threat_status`
  - Model `GenericRecoveryPoint` added property `threat_info`
  - Model `ILRRequestResource` added property `system_data`
  - Model `IaasVMRecoveryPoint` added property `threat_status`
  - Model `IaasVMRecoveryPoint` added property `threat_info`
  - Model `JobResource` added property `system_data`
  - Model `MabFileFolderProtectedItem` added property `source_side_scan_info`
  - Model `PrivateEndpointConnectionResource` added property `system_data`
  - Model `ProtectableContainerResource` added property `system_data`
  - Model `ProtectedItem` added property `source_side_scan_info`
  - Model `ProtectedItemResource` added property `system_data`
  - Model `ProtectionContainerResource` added property `system_data`
  - Model `ProtectionIntentResource` added property `system_data`
  - Model `ProtectionPolicyResource` added property `system_data`
  - Model `RecoveryPoint` added property `threat_status`
  - Model `RecoveryPoint` added property `threat_info`
  - Model `RecoveryPointResource` added property `system_data`
  - Model `Resource` added property `system_data`
  - Model `ResourceGuardProxyBaseResource` added property `system_data`
  - Model `RestoreRequestResource` added property `system_data`
  - Model `WorkloadItemResource` added property `system_data`
  - Model `WorkloadProtectableItemResource` added property `system_data`
  - Added model `ArmErrorDetail`
  - Added model `AzureVmWorkloadSAPHanaScaleoutProtectableItem`
  - Added model `AzureVmWorkloadSQLInstanceProtectedItem`
  - Added enum `CreatedByType`
  - Added model `DatabaseInRP`
  - Added model `ErrorResponse`
  - Added enum `InstanceProtectionReadiness`
  - Added model `PatchRecoveryPointInput`
  - Added model `PatchRecoveryPointPropertiesInput`
  - Added enum `ProtectionLevel`
  - Added model `ProxyResource`
  - Added model `SourceSideScanInfo`
  - Added enum `SourceSideScanStatus`
  - Added enum `SourceSideScanSummary`
  - Added model `SystemData`
  - Added model `ThreatInfo`
  - Added enum `ThreatSeverity`
  - Added enum `ThreatState`
  - Added enum `ThreatStatus`
  - Added model `UpdateRecoveryPointRequest`
  - Added enum `VMWorkloadPolicyType`
  - Operation group `ProtectedItemsOperations` added method `begin_create_or_update`

### Breaking Changes

  - This version introduces new hybrid models which have dual dictionary and model nature. Please follow https://aka.ms/azsdk/python/migrate/hybrid-models for migration.
  - For the method breakings, please refer to https://aka.ms/azsdk/python/migrate/operations for migration.
  - Model `Resource` deleted or renamed its instance variable `location`
  - Model `Resource` deleted or renamed its instance variable `tags`
  - Model `Resource` deleted or renamed its instance variable `e_tag`
  - Deleted or renamed model `BMSBackupEngineQueryObject`
  - Deleted or renamed model `BMSBackupEnginesQueryObject`
  - Deleted or renamed model `BMSBackupSummariesQueryObject`
  - Deleted or renamed model `BMSContainerQueryObject`
  - Deleted or renamed model `BMSContainersInquiryQueryObject`
  - Deleted or renamed model `BMSPOQueryObject`
  - Deleted or renamed model `BMSRPQueryObject`
  - Deleted or renamed model `BMSRefreshContainersQueryObject`
  - Deleted or renamed model `BMSWorkloadItemQueryObject`
  - Deleted or renamed model `ClientDiscoveryResponse`
  - Deleted or renamed model `CloudErrorBody`
  - Deleted or renamed model `ContainerType`
  - Deleted or renamed model `GetProtectedItemQueryObject`
  - Deleted or renamed model `HealthState`
  - Deleted or renamed model `IntentItemType`
  - Deleted or renamed model `JobOperationType`
  - Deleted or renamed model `JobQueryObject`
  - Deleted or renamed model `JobStatus`
  - Deleted or renamed model `NewErrorResponse`
  - Deleted or renamed model `NewErrorResponseError`
  - Deleted or renamed model `ProtectedItemQueryObject`
  - Deleted or renamed model `ProtectionIntentQueryObject`
  - Deleted or renamed model `ProtectionPolicyQueryObject`
  - Deleted or renamed model `RestorePointQueryType`
  - Deleted or renamed model `Type`
  - Method `BackupEnginesOperations.get` changed its parameter `skip_token` from `positional_or_keyword` to `keyword_only`
  - Method `BackupEnginesOperations.list` changed its parameter `skip_token` from `positional_or_keyword` to `keyword_only`
  - Method `BackupJobsOperations.list` changed its parameter `skip_token` from `positional_or_keyword` to `keyword_only`
  - Method `BackupProtectableItemsOperations.list` changed its parameter `skip_token` from `positional_or_keyword` to `keyword_only`
  - Method `BackupProtectedItemsOperations.list` changed its parameter `skip_token` from `positional_or_keyword` to `keyword_only`
  - Method `BackupProtectionIntentOperations.list` changed its parameter `skip_token` from `positional_or_keyword` to `keyword_only`
  - Method `BackupResourceVaultConfigsOperations.put` changed its parameter `x_ms_authorization_auxiliary` from `positional_or_keyword` to `keyword_only`
  - Method `BackupResourceVaultConfigsOperations.update` changed its parameter `x_ms_authorization_auxiliary` from `positional_or_keyword` to `keyword_only`
  - Method `BackupUsageSummariesOperations.list` changed its parameter `skip_token` from `positional_or_keyword` to `keyword_only`
  - Method `BackupWorkloadItemsOperations.list` changed its parameter `skip_token` from `positional_or_keyword` to `keyword_only`
  - Deleted or renamed method `ProtectedItemsOperations.create_or_update`
  - Method `ProtectionPoliciesOperations.create_or_update` changed its parameter `x_ms_authorization_auxiliary` from `positional_or_keyword` to `keyword_only`
  - Method `RestoresOperations.begin_trigger` changed its parameter `x_ms_authorization_auxiliary` from `positional_or_keyword` to `keyword_only`
  - Method `SecurityPINsOperations.get` changed its parameter `x_ms_authorization_auxiliary` from `positional_or_keyword` to `keyword_only`

### Other Changes

  - Deleted model `BackupEngineBaseResourceList`/`BackupManagementUsageList`/`JobResourceList`/`ProtectableContainerResourceList`/`ProtectedItemResourceList`/`ProtectionContainerResourceList`/`ProtectionIntentResourceList`/`ProtectionPolicyResourceList`/`RecoveryPointResourceList`/`ResourceGuardProxyBaseResourceList`/`WorkloadItemResourceList`/`WorkloadProtectableItemResourceList` which actually were not used by SDK users

## 10.0.0 (2025-10-16)

### Breaking Changes

  - Split module "passivestamp" into independent package [azure-mgmt-recoveryservicesbackup-passivestamp](https://pypi.org/project/azure-mgmt-recoveryservicesbackup-passivestamp/). Just add it as a dependency then no other code changes required.
  - Removed sub-namespace "activestamp" and just need update import from `from azure.mgmt.recoveryservicesbackup.activestamp import XXX` to `from azure.mgmt.recoveryservicesbackup import XXX`.

## 9.2.0 (2025-04-17)

### Features Added

  - Model `AzureFileShareRecoveryPoint` added property `recovery_point_tier_details`
  - Model `AzureIaaSClassicComputeVMProtectedItem` added property `policy_type`
  - Model `AzureIaaSComputeVMProtectedItem` added property `policy_type`
  - Model `AzureIaaSVMProtectedItem` added property `policy_type`
  - Model `AzureStorageContainer` added property `operation_type`
  - Enum `OperationType` added member `REHYDRATE`
  - Added model `AzureVmWorkloadSAPAseDatabaseProtectableItem`
  - Added model `AzureWorkloadSAPAsePointInTimeRecoveryPoint`
  - Added model `AzureWorkloadSAPAsePointInTimeRestoreRequest`
  - Added model `AzureWorkloadSAPAseRecoveryPoint`
  - Added model `AzureWorkloadSAPAseRestoreRequest`

## 9.1.0 (2024-04-22)

### Features Added

  - Model AzureIaaSVMProtectionPolicy has a new parameter snapshot_consistency_type
  - Model AzureWorkloadSAPHanaPointInTimeRestoreWithRehydrateRequest has a new parameter resource_guard_operation_requests
  - Model AzureWorkloadSAPHanaRestoreWithRehydrateRequest has a new parameter resource_guard_operation_requests
  - Model AzureWorkloadSQLPointInTimeRestoreWithRehydrateRequest has a new parameter resource_guard_operation_requests
  - Model AzureWorkloadSQLRestoreWithRehydrateRequest has a new parameter resource_guard_operation_requests
  - Model IaasVMRestoreWithRehydrationRequest has a new parameter resource_guard_operation_requests
  - Operation BackupResourceVaultConfigsOperations.put has a new optional parameter x_ms_authorization_auxiliary
  - Operation BackupResourceVaultConfigsOperations.update has a new optional parameter x_ms_authorization_auxiliary
  - Operation ProtectedItemsOperations.create_or_update has a new optional parameter x_ms_authorization_auxiliary
  - Operation ProtectionPoliciesOperations.create_or_update has a new optional parameter x_ms_authorization_auxiliary
  - Operation RestoresOperations.begin_trigger has a new optional parameter x_ms_authorization_auxiliary
  - Operation SecurityPINsOperations.get has a new optional parameter x_ms_authorization_auxiliary

## 9.0.0 (2024-01-24)

### Features Added

  - Added operation group FetchTieringCostOperations
  - Added operation group GetTieringCostOperationResultOperations
  - Added operation group TieringCostOperationStatusOperations
  - Model AzureFileShareProtectionPolicy has a new parameter vault_retention_policy
  - Model AzureWorkloadSAPHanaPointInTimeRestoreWithRehydrateRequest has a new parameter snapshot_restore_parameters
  - Model AzureWorkloadSAPHanaPointInTimeRestoreWithRehydrateRequest has a new parameter target_resource_group_name
  - Model AzureWorkloadSAPHanaPointInTimeRestoreWithRehydrateRequest has a new parameter user_assigned_managed_identity_details
  - Model AzureWorkloadSAPHanaRestoreWithRehydrateRequest has a new parameter snapshot_restore_parameters
  - Model AzureWorkloadSAPHanaRestoreWithRehydrateRequest has a new parameter target_resource_group_name
  - Model AzureWorkloadSAPHanaRestoreWithRehydrateRequest has a new parameter user_assigned_managed_identity_details
  - Model AzureWorkloadSQLPointInTimeRestoreWithRehydrateRequest has a new parameter snapshot_restore_parameters
  - Model AzureWorkloadSQLPointInTimeRestoreWithRehydrateRequest has a new parameter target_resource_group_name
  - Model AzureWorkloadSQLPointInTimeRestoreWithRehydrateRequest has a new parameter user_assigned_managed_identity_details
  - Model AzureWorkloadSQLRestoreWithRehydrateRequest has a new parameter snapshot_restore_parameters
  - Model AzureWorkloadSQLRestoreWithRehydrateRequest has a new parameter target_resource_group_name
  - Model AzureWorkloadSQLRestoreWithRehydrateRequest has a new parameter user_assigned_managed_identity_details
  - Model SubProtectionPolicy has a new parameter snapshot_backup_additional_details

### Breaking Changes

  - Parameter resource_guard_resource_id of model ResourceGuardProxyBase is now required

## 8.0.0 (2024-01-15)

### Features Added

  - Model AzureVmWorkloadSAPHanaDBInstanceProtectedItem has a new parameter vault_id
  - Model BackupStatusResponse has a new parameter acquire_storage_account_lock
  - Model BackupStatusResponse has a new parameter protected_items_count

### Breaking Changes

  - Renamed operation ProtectionContainersOperations.register to ProtectionContainersOperations.begin_register

## 7.0.0 (2023-09-18)

### Features Added

  - Added operation RecoveryPointsCrrOperations.get
  - Model AzureVmWorkloadProtectableItem has a new parameter is_protectable
  - Model AzureVmWorkloadSAPAseSystemProtectableItem has a new parameter is_protectable
  - Model AzureVmWorkloadSAPHanaDBInstance has a new parameter is_protectable
  - Model AzureVmWorkloadSAPHanaDBInstanceProtectedItem has a new parameter nodes_list
  - Model AzureVmWorkloadSAPHanaDBInstanceProtectedItem has a new parameter soft_delete_retention_period_in_days
  - Model AzureVmWorkloadSAPHanaDatabaseProtectableItem has a new parameter is_protectable
  - Model AzureVmWorkloadSAPHanaHSRProtectableItem has a new parameter is_protectable
  - Model AzureVmWorkloadSAPHanaSystemProtectableItem has a new parameter is_protectable
  - Model AzureVmWorkloadSQLAvailabilityGroupProtectableItem has a new parameter is_protectable
  - Model AzureVmWorkloadSQLAvailabilityGroupProtectableItem has a new parameter nodes_list
  - Model AzureVmWorkloadSQLDatabaseProtectableItem has a new parameter is_protectable
  - Model AzureVmWorkloadSQLInstanceProtectableItem has a new parameter is_protectable
  - Model BackupResourceVaultConfig has a new parameter soft_delete_retention_period_in_days
  - Model DistributedNodesInfo has a new parameter source_resource_id
  - Model InquiryValidation has a new parameter protectable_item_count

### Breaking Changes

  - Model AzureVmWorkloadSAPHanaDBInstanceProtectedItem no longer has parameter soft_delete_retention_period

## 6.0.0 (2023-05-04)

### Features Added

  - Model PrivateEndpointConnection has a new parameter group_ids
  - Model PrivateLinkServiceConnectionState has a new parameter actions_required

### Breaking Changes

  - Model PrivateLinkServiceConnectionState no longer has parameter action_required

## 5.2.0 (2023-03-20)

### Features Added

  - Model BMSRPQueryObject has a new parameter include_soft_deleted_rp
  - Model IaasVMRecoveryPoint has a new parameter is_private_access_enabled_on_any_disk
  - Model IaasVMRecoveryPoint has a new parameter security_type
  - Model IaasVMRestoreRequest has a new parameter extended_location
  - Model IaasVMRestoreRequest has a new parameter secured_vm_details
  - Model IaasVMRestoreRequest has a new parameter target_disk_network_access_settings
  - Model IaasVMRestoreWithRehydrationRequest has a new parameter extended_location
  - Model IaasVMRestoreWithRehydrationRequest has a new parameter secured_vm_details
  - Model IaasVMRestoreWithRehydrationRequest has a new parameter target_disk_network_access_settings
  - Model RecoveryPointProperties has a new parameter is_soft_deleted

## 5.1.0 (2023-01-30)

### Features Added

  - Added operation group DeletedProtectionContainersOperations
  - Model AzureIaaSVMProtectionPolicy has a new parameter tiering_policy
  - Model SubProtectionPolicy has a new parameter tiering_policy

## 5.1.0b3 (2023-01-03)

### Other Changes

  - Added generated samples in github repo
  - Drop support for python<3.7.0

## 5.1.0b2 (2022-10-19)

### Features Added

  - Added operation group DeletedProtectionContainersOperations
  - Model AzureVmWorkloadSAPHanaDBInstanceProtectedItem has a new parameter soft_delete_retention_period

## 5.1.0b1 (2022-08-29)

### Features Added

  - Model AzureIaaSVMProtectionPolicy has a new parameter tiering_policy
  - Model SubProtectionPolicy has a new parameter tiering_policy

## 5.0.0 (2022-05-16)

**Breaking changes**

  - Model AzureIaaSVMProtectionPolicy no longer has parameter tiering_policy
  - Model SubProtectionPolicy no longer has parameter tiering_policy
  - Operation ResourceGuardProxyOperations.put has a new parameter parameters

## 4.2.0 (2022-05-07)

**Features**

  - Model AzureIaaSVMProtectionPolicy has a new parameter tiering_policy
  - Model SubProtectionPolicy has a new parameter tiering_policy

## 4.1.1 (2022-02-18)

**Bug Fixes**

  - Fix multi-page paging  #23089

## 4.1.0 (2022-02-15)

**Features**

  - Model AzureIaaSVMProtectionPolicy has a new parameter policy_type

## 4.0.0 (2021-12-21)

**Breaking changes**

  - namespace splitted from `azure.mgmt.recoveryservicesbackup` to `azure.mgmt.recoveryservicesbackup.activestamp` and `azure.mgmt.recoveryservicesbackup.passivestamp`

## 3.0.0 (2021-10-19)

**Features**

  - Model GenericProtectedItem has a new parameter resource_guard_operation_requests
  - Model AzureSqlProtectedItem has a new parameter resource_guard_operation_requests
  - Model AzureFileshareProtectedItem has a new parameter resource_guard_operation_requests
  - Model AzureIaaSVMProtectionPolicy has a new parameter resource_guard_operation_requests
  - Model BackupResourceVaultConfig has a new parameter resource_guard_operation_requests
  - Model AzureIaaSVMProtectedItem has a new parameter resource_guard_operation_requests
  - Model AzureIaaSClassicComputeVMProtectedItem has a new parameter resource_guard_operation_requests
  - Model AzureFileShareProtectionPolicy has a new parameter resource_guard_operation_requests
  - Model DPMProtectedItem has a new parameter resource_guard_operation_requests
  - Model AzureVmWorkloadSAPAseDatabaseProtectedItem has a new parameter resource_guard_operation_requests
  - Model ProtectedItem has a new parameter resource_guard_operation_requests
  - Model AzureVmWorkloadSAPHanaDatabaseProtectedItem has a new parameter resource_guard_operation_requests
  - Model AzureVmWorkloadProtectionPolicy has a new parameter resource_guard_operation_requests
  - Model AzureIaaSComputeVMProtectedItem has a new parameter resource_guard_operation_requests
  - Model AzureFileshareProtectedItemAutoGenerated has a new parameter resource_guard_operation_requests
  - Model MabProtectionPolicy has a new parameter resource_guard_operation_requests
  - Model MabFileFolderProtectedItem has a new parameter resource_guard_operation_requests
  - Model GenericProtectionPolicy has a new parameter resource_guard_operation_requests
  - Model AzureVmWorkloadSQLDatabaseProtectedItem has a new parameter resource_guard_operation_requests
  - Model AzureSqlProtectionPolicy has a new parameter resource_guard_operation_requests
  - Model ProtectionPolicy has a new parameter resource_guard_operation_requests
  - Model AzureVmWorkloadProtectedItem has a new parameter resource_guard_operation_requests
  - Added operation group ResourceGuardProxyOperations
  - Added operation group BackupResourceStorageConfigsNonCRROperations
  - Added operation group ResourceGuardProxiesOperations

**Breaking changes**

  - Operation SecurityPINsOperations.get has a new signature

## 2.0.0 (2021-07-26)

**Features**

  - Model IaasVMRestoreRequest has a new parameter identity_info
  - Model IaasVMRestoreWithRehydrationRequest has a new parameter identity_info

**Breaking changes**

  - Removed operation group BackupResourceStorageConfigsNonCRROperations

## 1.1.0 (2021-07-22)

**Features**

  - Model AzureWorkloadPointInTimeRestoreRequest has a new parameter target_virtual_machine_id
  - Model AzureWorkloadSAPHanaPointInTimeRestoreRequest has a new parameter target_virtual_machine_id
  - Model AzureWorkloadSQLRestoreWithRehydrateRequest has a new parameter target_virtual_machine_id
  - Model AzureWorkloadSQLPointInTimeRestoreRequest has a new parameter target_virtual_machine_id
  - Model AzureWorkloadSQLRestoreRequest has a new parameter target_virtual_machine_id
  - Model AzureWorkloadSAPHanaRestoreWithRehydrateRequest has a new parameter target_virtual_machine_id
  - Model AzureWorkloadSAPHanaRestoreRequest has a new parameter target_virtual_machine_id
  - Model AzureWorkloadSAPHanaPointInTimeRestoreWithRehydrateRequest has a new parameter target_virtual_machine_id
  - Model AzureWorkloadSQLPointInTimeRestoreWithRehydrateRequest has a new parameter target_virtual_machine_id
  - Model AzureWorkloadRestoreRequest has a new parameter target_virtual_machine_id
  - Added operation group BackupResourceStorageConfigsNonCRROperations

## 1.0.0 (2021-05-26)

**Features**

  - Added operation group BackupUsageSummariesCRROperations

**Breaking changes**

  - Model AzureWorkloadSAPHanaPointInTimeRestoreRequest no longer has parameter target_virtual_machine_id
  - Model AzureWorkloadSAPHanaRestoreWithRehydrateRequest no longer has parameter target_virtual_machine_id
  - Model AzureWorkloadSQLRestoreWithRehydrateRequest no longer has parameter target_virtual_machine_id
  - Model AzureWorkloadRestoreRequest no longer has parameter target_virtual_machine_id
  - Model AzureWorkloadSAPHanaRestoreRequest no longer has parameter target_virtual_machine_id
  - Model AzureWorkloadSQLPointInTimeRestoreRequest no longer has parameter target_virtual_machine_id
  - Model AzureWorkloadSQLPointInTimeRestoreWithRehydrateRequest no longer has parameter target_virtual_machine_id
  - Model AzureWorkloadSQLRestoreRequest no longer has parameter target_virtual_machine_id
  - Model AzureWorkloadPointInTimeRestoreRequest no longer has parameter target_virtual_machine_id
  - Model AzureWorkloadSAPHanaPointInTimeRestoreWithRehydrateRequest no longer has parameter target_virtual_machine_id

## 1.0.0b1 (2021-05-14)

This is beta preview version.

This version uses a next-generation code generator that introduces important breaking changes, but also important new features (like unified authentication and async programming).

**General breaking changes**

- Credential system has been completly revamped:

  - `azure.common.credentials` or `msrestazure.azure_active_directory` instances are no longer supported, use the `azure-identity` classes instead: https://pypi.org/project/azure-identity/
  - `credentials` parameter has been renamed `credential`

- The `config` attribute no longer exists on a client, configuration should be passed as kwarg. Example: `MyClient(credential, subscription_id, enable_logging=True)`. For a complete set of
  supported options, see the [parameters accept in init documentation of azure-core](https://github.com/Azure/azure-sdk-for-python/blob/main/sdk/core/azure-core/CLIENT_LIBRARY_DEVELOPER.md#available-policies)
- You can't import a `version` module anymore, use `__version__` instead
- Operations that used to return a `msrest.polling.LROPoller` now returns a `azure.core.polling.LROPoller` and are prefixed with `begin_`.
- Exceptions tree have been simplified and most exceptions are now `azure.core.exceptions.HttpResponseError` (`CloudError` has been removed).
- Most of the operation kwarg have changed. Some of the most noticeable:

  - `raw` has been removed. Equivalent feature can be found using `cls`, a callback that will give access to internal HTTP response for advanced user
  - For a complete set of
  supported options, see the [parameters accept in Request documentation of azure-core](https://github.com/Azure/azure-sdk-for-python/blob/main/sdk/core/azure-core/CLIENT_LIBRARY_DEVELOPER.md#available-policies)

**General new features**

- Type annotations support using `typing`. SDKs are mypy ready.
- This client has now stable and official support for async. Check the `aio` namespace of your package to find the async client.
- This client now support natively tracing library like OpenCensus or OpenTelemetry. See this [tracing quickstart](https://github.com/Azure/azure-sdk-for-python/tree/main/sdk/core/azure-core-tracing-opentelemetry) for an overview.

## 0.11.0 (2020-12-28)

**Features**

  - Model IaasVMRecoveryPoint has a new parameter zones
  - Model IaasVMRestoreRequest has a new parameter zones

## 0.10.0 (2020-12-08)

**Features**

  - Model IaasVMRestoreRequest has a new parameter disk_encryption_set_id
  - Model IaasVMRestoreRequest has a new parameter restore_with_managed_disks
  - Model BackupResourceConfig has a new parameter cross_region_restore_flag
  - Model AzureFileshareProtectedItem has a new parameter health_status
  - Added operation RecoveryPointsOperations.get_access_token
  - Added operation group AadPropertiesOperations
  - Added operation group CrossRegionRestoreOperations
  - Added operation group BackupCrrJobDetailsOperations
  - Added operation group PrivateEndpointOperations
  - Added operation group BackupCrrJobsOperations
  - Added operation group RecoveryPointsCrrOperations
  - Added operation group CrrOperationResultsOperations
  - Added operation group CrrOperationStatusOperations
  - Added operation group BackupProtectedItemsCrrOperations

**Breaking changes**

  - Removed operation RecoveryServicesBackupClientOperationsMixin.get_operation_status1

## 0.9.0 (2020-12-07)

**Features**

  - Model AzureFileshareProtectedItem has a new parameter kpis_healths
  - Model AzureIaaSVMProtectedItem has a new parameter kpis_healths
  - Model AzureIaaSClassicComputeVMProtectedItem has a new parameter kpis_healths
  - Model AzureVmWorkloadProtectedItem has a new parameter kpis_healths
  - Model AzureVmWorkloadSAPHanaDatabaseProtectedItem has a new parameter kpis_healths
  - Model AzureIaaSComputeVMProtectedItem has a new parameter kpis_healths
  - Model AzureVmWorkloadSAPAseDatabaseProtectedItem has a new parameter kpis_healths
  - Model AzureVmWorkloadSQLDatabaseProtectedItem has a new parameter kpis_healths
  - Added operation RecoveryServicesBackupClientOperationsMixin.bms_prepare_data_move
  - Added operation RecoveryServicesBackupClientOperationsMixin.bms_trigger_data_move
  - Added operation RecoveryServicesBackupClientOperationsMixin.get_operation_status1
  - Added operation group BackupResourceEncryptionConfigsOperations
  - Added operation group BMSPrepareDataMoveOperationResultOperations

**Breaking changes**

  - Model AzureFileshareProtectedItem no longer has parameter health_status
  - Model AzureFileshareProtectedItem no longer has parameter health_details
  - Model AzureVmWorkloadProtectedItem no longer has parameter health_status
  - Model AzureVmWorkloadProtectedItem no longer has parameter health_details
  - Model AzureVmWorkloadSAPHanaDatabaseProtectedItem no longer has parameter health_status
  - Model AzureVmWorkloadSAPHanaDatabaseProtectedItem no longer has parameter health_details
  - Model AzureVmWorkloadSAPAseDatabaseProtectedItem no longer has parameter health_status
  - Model AzureVmWorkloadSAPAseDatabaseProtectedItem no longer has parameter health_details
  - Model AzureVmWorkloadSQLDatabaseProtectedItem no longer has parameter health_status
  - Model AzureVmWorkloadSQLDatabaseProtectedItem no longer has parameter health_details

## 0.8.0 (2020-06-05)

**Features**

  - Model AzureVmWorkloadSAPHanaDatabaseProtectedItem has a new parameter health_details
  - Model AzureVmWorkloadSAPHanaDatabaseProtectedItem has a new parameter health_status
  - Model AzureVmWorkloadSQLDatabaseProtectedItem has a new parameter health_details
  - Model AzureVmWorkloadSQLDatabaseProtectedItem has a new parameter health_status
  - Model AzureFileshareProtectedItem has a new parameter health_details
  - Model AzureVmWorkloadSAPAseDatabaseProtectedItem has a new parameter health_details
  - Model AzureVmWorkloadSAPAseDatabaseProtectedItem has a new parameter health_status
  - Model AzureVmWorkloadProtectedItem has a new parameter health_details
  - Model AzureVmWorkloadProtectedItem has a new parameter health_status

## 0.7.0 (2020-03-24)

**Features**

  - Added operation BackupResourceVaultConfigsOperations.put
  - Added operation group RecoveryServicesBackupClientOperationsMixin
  - Added operation group PrivateEndpointConnectionOperations

## 0.6.0 (2020-01-14)

**Features**

  - Model TargetRestoreInfo has a new parameter
    target_directory_for_file_restore
  - Model AzureIaaSVMProtectionPolicy has a new parameter
    instant_rp_details

## 0.5.0 (2019-11-21)

**Features**

  - Model AzureVmWorkloadProtectedItem has a new parameter
    deferred_delete_time_remaining
  - Model AzureVmWorkloadProtectedItem has a new parameter
    is_deferred_delete_schedule_upcoming
  - Model AzureVmWorkloadProtectedItem has a new parameter is_rehydrate
  - Model AzureVmWorkloadProtectedItem has a new parameter
    deferred_delete_time_in_utc
  - Model AzureVmWorkloadProtectedItem has a new parameter
    is_scheduled_for_deferred_delete
  - Model AzureFileshareProtectedItemExtendedInfo has a new parameter
    resource_state
  - Model AzureFileshareProtectedItemExtendedInfo has a new parameter
    resource_state_sync_time
  - Model AzureIaaSClassicComputeVMProtectedItem has a new parameter
    deferred_delete_time_remaining
  - Model AzureIaaSClassicComputeVMProtectedItem has a new parameter
    is_deferred_delete_schedule_upcoming
  - Model AzureIaaSClassicComputeVMProtectedItem has a new parameter
    extended_properties
  - Model AzureIaaSClassicComputeVMProtectedItem has a new parameter
    is_rehydrate
  - Model AzureIaaSClassicComputeVMProtectedItem has a new parameter
    deferred_delete_time_in_utc
  - Model AzureIaaSClassicComputeVMProtectedItem has a new parameter
    is_scheduled_for_deferred_delete
  - Model AzureWorkloadSAPHanaPointInTimeRestoreRequest has a new
    parameter recovery_mode
  - Model AzureVmWorkloadProtectionPolicy has a new parameter
    make_policy_consistent
  - Model AzureIaaSVMProtectedItem has a new parameter
    deferred_delete_time_remaining
  - Model AzureIaaSVMProtectedItem has a new parameter
    is_deferred_delete_schedule_upcoming
  - Model AzureIaaSVMProtectedItem has a new parameter
    extended_properties
  - Model AzureIaaSVMProtectedItem has a new parameter is_rehydrate
  - Model AzureIaaSVMProtectedItem has a new parameter
    deferred_delete_time_in_utc
  - Model AzureIaaSVMProtectedItem has a new parameter
    is_scheduled_for_deferred_delete
  - Model DPMProtectedItem has a new parameter
    deferred_delete_time_in_utc
  - Model DPMProtectedItem has a new parameter is_rehydrate
  - Model DPMProtectedItem has a new parameter
    deferred_delete_time_remaining
  - Model DPMProtectedItem has a new parameter
    is_deferred_delete_schedule_upcoming
  - Model AzureWorkloadRestoreRequest has a new parameter recovery_mode
  - Model AzureWorkloadSAPHanaRestoreRequest has a new parameter
    recovery_mode
  - Model ProtectedItem has a new parameter
    deferred_delete_time_remaining
  - Model ProtectedItem has a new parameter
    is_deferred_delete_schedule_upcoming
  - Model ProtectedItem has a new parameter is_rehydrate
  - Model ProtectedItem has a new parameter
    deferred_delete_time_in_utc
  - Model ProtectedItem has a new parameter
    is_scheduled_for_deferred_delete
  - Model AzureWorkloadSQLRestoreRequest has a new parameter
    recovery_mode
  - Model InquiryValidation has a new parameter additional_detail
  - Model AzureVmWorkloadSQLDatabaseProtectedItem has a new parameter
    deferred_delete_time_remaining
  - Model AzureVmWorkloadSQLDatabaseProtectedItem has a new parameter
    is_deferred_delete_schedule_upcoming
  - Model AzureVmWorkloadSQLDatabaseProtectedItem has a new parameter
    is_rehydrate
  - Model AzureVmWorkloadSQLDatabaseProtectedItem has a new parameter
    deferred_delete_time_in_utc
  - Model AzureVmWorkloadSQLDatabaseProtectedItem has a new parameter
    is_scheduled_for_deferred_delete
  - Model AzureVmWorkloadSAPAseDatabaseProtectedItem has a new parameter
    deferred_delete_time_remaining
  - Model AzureVmWorkloadSAPAseDatabaseProtectedItem has a new parameter
    is_deferred_delete_schedule_upcoming
  - Model AzureVmWorkloadSAPAseDatabaseProtectedItem has a new parameter
    is_rehydrate
  - Model AzureVmWorkloadSAPAseDatabaseProtectedItem has a new parameter
    deferred_delete_time_in_utc
  - Model AzureVmWorkloadSAPAseDatabaseProtectedItem has a new parameter
    is_scheduled_for_deferred_delete
  - Model AzureWorkloadSQLPointInTimeRestoreRequest has a new parameter
    recovery_mode
  - Model AzureIaaSComputeVMProtectedItem has a new parameter
    deferred_delete_time_remaining
  - Model AzureIaaSComputeVMProtectedItem has a new parameter
    is_deferred_delete_schedule_upcoming
  - Model AzureIaaSComputeVMProtectedItem has a new parameter
    extended_properties
  - Model AzureIaaSComputeVMProtectedItem has a new parameter
    is_rehydrate
  - Model AzureIaaSComputeVMProtectedItem has a new parameter
    deferred_delete_time_in_utc
  - Model AzureIaaSComputeVMProtectedItem has a new parameter
    is_scheduled_for_deferred_delete
  - Model IaasVMRestoreRequest has a new parameter
    restore_disk_lun_list
  - Model AzureFileShareRecoveryPoint has a new parameter
    recovery_point_size_in_gb
  - Model BackupResourceVaultConfig has a new parameter
    soft_delete_feature_state
  - Model AzureVmWorkloadSAPHanaDatabaseProtectedItem has a new
    parameter deferred_delete_time_remaining
  - Model AzureVmWorkloadSAPHanaDatabaseProtectedItem has a new
    parameter is_deferred_delete_schedule_upcoming
  - Model AzureVmWorkloadSAPHanaDatabaseProtectedItem has a new
    parameter is_rehydrate
  - Model AzureVmWorkloadSAPHanaDatabaseProtectedItem has a new
    parameter deferred_delete_time_in_utc
  - Model AzureVmWorkloadSAPHanaDatabaseProtectedItem has a new
    parameter is_scheduled_for_deferred_delete
  - Model MabFileFolderProtectedItem has a new parameter
    last_backup_time
  - Model MabFileFolderProtectedItem has a new parameter
    deferred_delete_time_remaining
  - Model MabFileFolderProtectedItem has a new parameter
    is_deferred_delete_schedule_upcoming
  - Model MabFileFolderProtectedItem has a new parameter is_rehydrate
  - Model MabFileFolderProtectedItem has a new parameter
    deferred_delete_time_in_utc
  - Model IaasVMRecoveryPoint has a new parameter
    recovery_point_disk_configuration
  - Model GenericProtectedItem has a new parameter
    deferred_delete_time_remaining
  - Model GenericProtectedItem has a new parameter
    is_deferred_delete_schedule_upcoming
  - Model GenericProtectedItem has a new parameter is_rehydrate
  - Model GenericProtectedItem has a new parameter
    deferred_delete_time_in_utc
  - Model GenericProtectedItem has a new parameter
    is_scheduled_for_deferred_delete
  - Model AzureWorkloadPointInTimeRestoreRequest has a new parameter
    recovery_mode
  - Model ExportJobsOperationResultInfo has a new parameter
    excel_file_blob_sas_key
  - Model ExportJobsOperationResultInfo has a new parameter
    excel_file_blob_url
  - Model AzureFileshareProtectedItem has a new parameter
    deferred_delete_time_remaining
  - Model AzureFileshareProtectedItem has a new parameter
    is_deferred_delete_schedule_upcoming
  - Model AzureFileshareProtectedItem has a new parameter is_rehydrate
  - Model AzureFileshareProtectedItem has a new parameter
    deferred_delete_time_in_utc
  - Model AzureFileshareProtectedItem has a new parameter
    is_scheduled_for_deferred_delete
  - Model AzureSqlProtectedItem has a new parameter
    deferred_delete_time_remaining
  - Model AzureSqlProtectedItem has a new parameter
    is_deferred_delete_schedule_upcoming
  - Model AzureSqlProtectedItem has a new parameter is_rehydrate
  - Model AzureSqlProtectedItem has a new parameter
    deferred_delete_time_in_utc
  - Model AzureSqlProtectedItem has a new parameter
    is_scheduled_for_deferred_delete

**General Breaking changes**

This version uses a next-generation code generator that might introduce
breaking changes if from some import. In summary, some modules were
incorrectly visible/importable and have been renamed. This fixed several
issues caused by usage of classes that were not supposed to be used in
the first place. RecoveryServicesBackupClient cannot be imported from
azure.mgmt.recoveryservicesbackup.recovery_services_backup_client
anymore (import from azure.mgmt.recoveryservicesbackup works like
before) RecoveryServicesBackupClientConfiguration import has been moved
from
azure.mgmt.recoveryservicesbackup.recovery_services_backup_client to
azure.mgmt.recoveryservicesbackup A model MyClass from a "models"
sub-module cannot be imported anymore using
azure.mgmt.recoveryservicesbackup.models.my_class (import from
azure.mgmt.recoveryservicesbackup.models works like before) An operation
class MyClassOperations from an operations sub-module cannot be imported
anymore using
azure.mgmt.recoveryservicesbackup.operations.my_class_operations
(import from azure.mgmt.recoveryservicesbackup.operations works like
before) Last but not least, HTTP connection pooling is now enabled by
default. You should always use a client as a context manager, or call
close(), or use no more than one client per process.

## 0.4.0 (2019-05-21)

**Features**

  - Model AzureWorkloadRestoreRequest has a new parameter target_info
  - Model AzureVmWorkloadSAPHanaDatabaseProtectableItem has a new
    parameter is_auto_protected
  - Model AzureVmWorkloadSAPHanaSystemProtectableItem has a new
    parameter is_auto_protected
  - Model AzureIaaSVMJobTaskDetails has a new parameter
    task_execution_details
  - Model AzureWorkloadContainer has a new parameter operation_type
  - Model AzureVmWorkloadSQLInstanceProtectableItem has a new parameter
    is_auto_protected
  - Model AzureIaaSVMJobExtendedInfo has a new parameter
    estimated_remaining_duration
  - Model AzureVmWorkloadSQLAvailabilityGroupProtectableItem has a new
    parameter is_auto_protected
  - Model AzureVmWorkloadProtectableItem has a new parameter
    is_auto_protected
  - Model AzureVMAppContainerProtectionContainer has a new parameter
    operation_type
  - Model AzureSQLAGWorkloadContainerProtectionContainer has a new
    parameter operation_type
  - Model AzureVmWorkloadSQLDatabaseProtectableItem has a new parameter
    is_auto_protected
  - Added operation BackupResourceStorageConfigsOperations.patch
  - Added operation ProtectionIntentOperations.delete
  - Added operation ProtectionIntentOperations.get
  - Added operation group BackupProtectionIntentOperations
  - Added operation group OperationOperations

## 0.3.0 (2018-06-27)

**Features**

  - SAP HANA contract changes (new filters added to existing API's.).
    This feature is still in development phase and not open for usage
    yet.
  - Instant RP field added in create policy.
  - Comments added for some contracts.

**Python details**

  - Model DPMProtectedItem has a new parameter create_mode
  - Model MabFileFolderProtectedItem has a new parameter create_mode
  - Model AzureIaaSClassicComputeVMProtectedItem has a new parameter
    create_mode
  - Model AzureWorkloadContainer has a new parameter workload_type
  - Model AzureIaaSVMProtectionPolicy has a new parameter
    instant_rp_retention_range_in_days
  - Model AzureFileshareProtectedItem has a new parameter create_mode
  - Model AzureSQLAGWorkloadContainerProtectionContainer has a new
    parameter workload_type
  - Model AzureSqlProtectedItem has a new parameter create_mode
  - Model AzureIaaSVMJobExtendedInfo has a new parameter
    internal_property_bag
  - Model KeyAndSecretDetails has a new parameter encryption_mechanism
  - Model AzureIaaSVMProtectedItem has a new parameter create_mode
  - Model AzureVMAppContainerProtectionContainer has a new parameter
    workload_type
  - Model AzureVmWorkloadSQLDatabaseProtectedItem has a new parameter
    create_mode
  - Model IaasVMRecoveryPoint has a new parameter os_type
  - Model ProtectionPolicyQueryObject has a new parameter workload_type
  - Model AzureIaaSComputeVMProtectedItem has a new parameter
    create_mode
  - Model Settings has a new parameter is_compression
  - Model GenericProtectedItem has a new parameter create_mode
  - Model AzureWorkloadJob has a new parameter workload_type
  - Model ProtectedItem has a new parameter create_mode
  - Operation ProtectionContainersOperations.inquire has a new "filter"
    parameter

## 0.2.0 (2018-05-25)

**Features**

  - Client class can be used as a context manager to keep the underlying
    HTTP session open for performance

**General Breaking changes**

This version uses a next-generation code generator that *might*
introduce breaking changes.

  - Model signatures now use only keyword-argument syntax. All
    positional arguments must be re-written as keyword-arguments. To
    keep auto-completion in most cases, models are now generated for
    Python 2 and Python 3. Python 3 uses the "*" syntax for
    keyword-only arguments.
  - Enum types now use the "str" mixin (class AzureEnum(str, Enum)) to
    improve the behavior when unrecognized enum values are encountered.
    While this is not a breaking change, the distinctions are important,
    and are documented here:
    <https://docs.python.org/3/library/enum.html#others> At a glance:
      - "is" should not be used at all.
      - "format" will return the string value, where "%s" string
        formatting will return `NameOfEnum.stringvalue`. Format syntax
        should be prefered.
  - New Long Running Operation:
      - Return type changes from
        `msrestazure.azure_operation.AzureOperationPoller` to
        `msrest.polling.LROPoller`. External API is the same.
      - Return type is now **always** a `msrest.polling.LROPoller`,
        regardless of the optional parameters used.
      - The behavior has changed when using `raw=True`. Instead of
        returning the initial call result as `ClientRawResponse`,
        without polling, now this returns an LROPoller. After polling,
        the final resource will be returned as a `ClientRawResponse`.
      - New `polling` parameter. The default behavior is
        `Polling=True` which will poll using ARM algorithm. When
        `Polling=False`, the response of the initial call will be
        returned without polling.
      - `polling` parameter accepts instances of subclasses of
        `msrest.polling.PollingMethod`.
      - `add_done_callback` will no longer raise if called after
        polling is finished, but will instead execute the callback right
        away.

**Bugfixes**

  - Compatibility of the sdist with wheel 0.31.0

## 0.1.2 (2019-03-12)

  - Updating permissible versions of the msrestazure package to unblock
    [Azure/azure-cli#6973](https://github.com/Azure/azure-cli/issues/6973).

## 0.1.1 (2017-08-09)

**Bug fixes**

  - Fix duration parsing (#1214)

## 0.1.0 (2017-06-05)

  - Initial Release
